package com.emsoft.data.net

import com.emsoft.common.Assert
import com.emsoft.data.DataManagerImpl
import groovyx.net.http.RESTClient

/**
 * Manages data throught REST service.
 *
 * @author Vladimir Zhukov
 *
 */
class RESTDataManager extends DataManagerImpl<RESTDataManager> {

    private String defaultURI
    private RESTClient client

    RESTDataManager(String defaultURI) {
        Assert.hasText(defaultURI, "defaultURI")
        this.defaultURI = defaultURI
    }

    RESTDataManager(RESTDataManager dataManager) {
        super(dataManager)
    }

    @Override
    protected boolean openCore() {
        client = new RESTClient(defaultURI)
        return true
    }

    @Override
    protected boolean closeCore() {
        client.shutdown()
        client = null
        return true
    }

    @Override
    protected boolean isOpenCore() {
        return client != null
    }

    protected RESTClient getRestClient() {
        checkOpen()
        return (externalDataManager != null ? externalDataManager.restClient : client)
    }
}